.. _example_gallery:

Elasticipy Example Gallery
==========================

Welcome to the **Elasticipy** example gallery!
This page contains a collection of plotting capabilities of the Elasticipy package for various types of objects.

.. toctree::
   :hidden:
   :glob:

   auto_examples/*
